@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: G.pm,v 1.4 2002/07/30 17:40:56 gaou Exp $
@@ -30,8 +28,10 @@
 #
 
 package G;
+require 5.008;
 
 use strict;
+use base qw(G::IO Exporter);
 
 # import core extensions
 use SubOpt;
@@ -42,7 +42,6 @@ use G::Messenger;
 use G::Inspire;
 
 # import core modules
-require G::IO::Handler;
 require G::DynamicLoader;
 
 # import db classes
@@ -82,7 +81,6 @@ use G::Tools::GOA;
 use G::Tools::GlimmerM;
 use G::Tools::Literature;
 use G::Tools::KEGG_API;
-use G::Tools::KEGG_API3;
 use G::Tools::PEC;
 use G::Tools::Statistics;
 use G::Tools::GMap;
@@ -100,10 +98,7 @@ use G::System::CHI;
 use G::System::ReL8;
 use G::System::FuncD;
 
-require Exporter;
-
-our @ISA = qw(G::IO Exporter);
-our @EXPORT;
+our @EXPORT = qw(load);
 
 # export odyssay functions
 push(@EXPORT, @G::Seq::AminoAcid::EXPORT);
@@ -138,7 +133,6 @@ push(@EXPORT, @G::Tools::GOA::EXPORT);
 push(@EXPORT, @G::Tools::GlimmerM::EXPORT);
 push(@EXPORT, @G::Tools::Literature::EXPORT);
 push(@EXPORT, @G::Tools::KEGG_API::EXPORT);
-push(@EXPORT, @G::Tools::KEGG_API3::EXPORT);
 push(@EXPORT, @G::Tools::PEC::EXPORT);
 push(@EXPORT, @G::Tools::Statistics::EXPORT);
 push(@EXPORT, @G::Tools::GMap::EXPORT);
@@ -167,6 +161,9 @@ our $VERSION = $G::IO::VERSION;
 
 mkdir($ENV{HOME} . '/.glang/data/');
 
+sub load{
+    return new G(@_);
+}
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -185,6 +182,7 @@ G - G-language Genome Analysis Environment core interface module
  use G;                          # Imports G-language GAE module 
    
  $gb = new G("ecoli.gbk");       # Creates G's instance as $gb 
+ $gb =  load("ecoli.gbk");       # this line is same as the above.
                                  # At the same time, read in ecoli.gbk. 
                                  # Read the annotation and sequence 
                                  # information 
@@ -267,17 +265,35 @@ G - G-language Genome Analysis Environment core interface module
 
      Name: $gb = new G("genome file")   -   create a G instance
 
-         Creates a G instance.
+     see "help load" for more information.
+
+=cut
+
+=head2 load
+
+     Name: load   -   load genome databases
+
+         This funciton is used to load genome databases into memory.
          First option is the filename of the database. Default format is
          the GenBank database. Database format is guessed from the extensions.
          (eg. .gbk => GenBank, .fasta => FASTA, .embl => EMBL)
 
          There are also several sample bacterial genomes included in the system.
-         $eco   = new G("ecoli"); # Escherichia coli K12 MG1655 - NC_000913
-         $bsub  = new G("bsub");  # Bacillus subtilis           - NC_000964
-         $mgen  = new G("mgen");  # Mycoplasma genitalium       - NC_000908
-         $cyano = new G("cyano"); # Synechococcus sp.           - NC_005070
-         $pyro  = new G("pyro");  # Pyrococcus furiosus         - NC_003413
+         $eco   = load("ecoli"); # Escherichia coli K12 MG1655 - NC_000913
+         $bsub  = load("bsub");  # Bacillus subtilis           - NC_000964
+         $mgen  = load("mgen");  # Mycoplasma genitalium       - NC_000908
+         $cyano = load("cyano"); # Synechococcus sp.           - NC_005070
+         $pyro  = load("pyro");  # Pyrococcus furiosus         - NC_003413
+
+         Data can be automatically donwloaded from public databases using
+         Uniform Sequence Address (USA) keys.
+         http://emboss.sourceforge.net/docs/themes/UniformSequenceAddress.html
+         Currently supported database keys are: 
+            swiss, genbank, genpept, embl, refseq 
+         eg. 
+            $gb = load("embl:xlrhodop");
+            $gb = load("genbank:AY063336")
+            $gb = load("swiss:ROA1_HUMAN")
 
          Second option specifies detailed actions.
 
@@ -298,7 +314,7 @@ G - G-language Genome Analysis Environment core interface module
            'bioperl'                 this option creates a G instance from 
                                      a bioperl object. 
                                      eg. $bp = $bp->next_seq();       # bioperl
-                                         $gb = new G($bp, "bioperl"); # G
+                                         $gb = load($bp, "bioperl"); # G
 
            'longest ORF annotation'  this option predicts genes with longest ORF
                                      algorithm (longest frame from start codon
@@ -324,7 +340,7 @@ G - G-language Genome Analysis Environment core interface module
            'ace'                this option loads a ace   format database.
            'net GenBank'        this option loads a GenBank format database from 
                                 NCBI database. With this option, the first value to 
-                                pass to new() function will be the accession 
+                                pass to load() function will be the accession 
                                 number of the database.
 
 =cut
