@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -27,15 +25,14 @@
 package G::DB::BDB;
 
 use strict;
+use base qw(Exporter);
+
 use DBI;
+
 use SubOpt;
 use G::DB::SDB;
 
-require G::IO;
 require G::DB::Handler;
-require Exporter;
-
-our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
 		 db_dbi
