@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: G::IO.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -32,28 +30,20 @@
 package G::IO;
 
 use strict;
-
-use Bio::SeqIO;
-use Bio::DB::GenBank;
-use Bio::DB::RefSeq;
-use Bio::Perl;
+use base qw(G::IO::Handler G::IO::GenBankI G::IO::GenBankO G::DB::Handler);
+use autouse 'Bio::Perl'=>qw(read_sequence write_sequence get_sequence);
 
 use G::Messenger;
 use G::DB::SDB;
 use G::IO::Annotation;
 
-require G::IO::GenBankI;
-require G::IO::GenBankO;
 require G::IO::FastaI;
 require G::IO::EmblI;
-require G::IO::Handler;
-require G::DB::Handler;
 
 use File::Basename;
 use File::ShareDir ':ALL';
 
-our @ISA = qw(G::IO::Handler G::IO::GenBankI G::IO::GenBankO G::DB::Handler);
-our $VERSION = '1.7.6';
+our $VERSION = '1.8.0';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -318,7 +308,7 @@ sub loaded_msg {
                  Arakawa K. et al. (2006) Journal of Pestice Science.
 
  	      License: GNU General Public License
-	      Copyright (C) 2001-2007 G-language Project
+	      Copyright (C) 2001-2008 G-language Project
 	      Institute for Advanced Biosciences, Keio University, JAPAN 
 
 	     __/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/__/
@@ -369,6 +359,7 @@ sub interpret_format {
     }elsif ($filename =~ /^(?:[A-Z]|[A-Z][A-Z]).\d+$/i){
 	return 'net GenBank';
     }else{
+	require Bio::SeqIO;
 	my $format = Bio::SeqIO->_guess_format($filename);
 
 	if (length $format){
@@ -408,6 +399,7 @@ sub output {
 }
 
 sub bioperl {
+    require Bio::SeqIO;
     my $this = shift;
     my $outfile = _generate_tmpfilename();
     $this->output($outfile);
