@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Util.pm,v 1.1.1.1 2002/04/02 20:25:43 gaou Exp $
@@ -39,17 +37,13 @@ use G::Tools::Statistics;
 use G::Seq::GCskew;
 use G::DB::SDB;
 
-use strict;
-use Cwd;
 use GD;
-use SVG;
+
+use strict;
+use base qw(Exporter);
+use autouse 'Cwd'=>qw(getcwd);
 use SelfLoader;
 
-
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 		 dnawalk
 		 genome_map
@@ -477,6 +471,8 @@ sub genome_map {
 
 
 sub genome_map2 {
+    require SVG;
+
     &opt_default(output=>"show", window=>50, type=>"CDS", 
 		 start=>1, end=>100000, filename=>"genome_map.svg", ptt=>'', cgi=>0);
     my @args = opt_get(@_);
@@ -1298,6 +1294,8 @@ sub seq2png {
 
 
 sub plasmid_map{
+    require SVG;
+
     opt_default(ptt=>'', output=>'show', filename=>"plasmid_map.svg", cgi=>0);
     my @args = opt_get(@_);
     my $gb = shift;
@@ -1499,6 +1497,8 @@ sub plasmid_map{
 
 
 sub circular_map{
+    require SVG;
+
     my $gb = opt_as_gb(shift);
 
     mkdir( "data", 0777 );
