@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -30,12 +28,9 @@
 package G::Shell::Help;
 
 use strict;
+use base qw(Exporter);
+use autouse 'String::Approx'=>qw(amatch);
 use File::Find;
-use String::Approx 'amatch';
-
-require Exporter;
-
-our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
 		 help
