@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Cap3.pm,v 1.4 2002/08/19 17:22:45 tero Exp $
@@ -29,20 +27,15 @@
 package G::Tools::Blast;
 
 use SubOpt;
-use Cwd;
 use G::Messenger;
 use G::Seq::Primitive;
-use Bio::Tools::Run::StandAloneBlast;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
+use autouse 'Cwd'=>qw(getcwd);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
+our @EXPORT = qw(
 	     _blast_tp_finder
 	     _blast
 	     _formatdb
@@ -422,6 +415,7 @@ sub _blast_tp_finder{
 
 
 sub mapping_blast2{
+    require Bio::Tools::Run::StandAloneBlast;
     msg_send("####################BLAST_SEARCHSTART#####################\n");
 
     &opt_default(clustering=>"off", p=>"blastn",database=>"genome_file",query=>"cDNA_dir\/",
