@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: SubOpt.pm,v 1.3 2002/07/30 17:40:56 gaou Exp $
@@ -35,10 +33,7 @@ use G::Messenger;
 require G::IO;
 
 use strict;
-
-require Exporter;
-
-our @ISA = qw(Exporter);
+use base qw(Exporter);
 
 our @EXPORT = qw(
 		 opt_default
@@ -114,8 +109,10 @@ sub opt_get{
     my $i = 0;
     my @bparray = ();
 
-    while(defined $args[$i]){
+    mkdir ("data", 0777);
+    mkdir ("graph", 0777);
 
+    while(defined $args[$i]){
 	if (substr($args[$i], 0, 1) eq '-' && substr($args[$i], 1, 1) !~ /[0-9]/){
 	    $data{substr($args[$i],1)} = $args[$i + 1];
 	    $i += 2;
@@ -140,7 +137,7 @@ __END__
 
 =head1 NAME
 
-SubOpt - Odyssey Subroutine Input API
+SubOpt - G-language Subroutine Input API
 
 =head1 SYNOPSIS
 
